@@ -31,6 +31,8 @@
 #include <KConfigGroup>
 #include <KLineEdit>
 #include <KLocalizedString>
+#include <KLazyLocalizedString>
+
 //BEGIN Kolf::Bumper
 
 Kolf::Bumper::Bumper(QGraphicsItem* parent, b2World* world)
@@ -399,16 +401,18 @@ void Kolf::RectangleOverlay::moveHandle(const QPointF& handleScenePos)
 //END Kolf::RectangleOverlay
 //BEGIN Kolf::RectangleConfig
 
+
 Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* parent)
 	: Config(parent)
 	, m_layout(new QGridLayout(this))
 	, m_wallCheckBoxes(Kolf::RectangleWallCount, nullptr)
 	, m_item(item)
 {
-	static const char* captions[] = { I18N_NOOP("&Top"), I18N_NOOP("&Left"), I18N_NOOP("&Right"), I18N_NOOP("&Bottom") };
+    static const KLazyLocalizedString captions[] =
+        { kli18n("&Top"), kli18n("&Left"), kli18n("&Right"), kli18n("&Bottom") };
 	for (int i = 0; i < Kolf::RectangleWallCount; ++i)
 	{
-		QCheckBox* checkBox = m_wallCheckBoxes[i] = new QCheckBox(i18n(captions[i]), this);
+        QCheckBox* checkBox = m_wallCheckBoxes[i] = new QCheckBox(captions[i].toString(), this);
 		checkBox->setEnabled(item->isWallAllowed((Kolf::WallIndex) i));
 		checkBox->setChecked(item->hasWall((Kolf::WallIndex) i));
 		connect(checkBox, &QCheckBox::toggled, this, &Kolf::RectangleConfig::setWall);
